<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="2.0"
    xmlns:func="http://www.oxygenxml.com/xsdDoc/functions" xmlns="http://www.w3.org/1999/xhtml">
    <xsl:param name="mainFile" required="no">index.html</xsl:param>
    <!--<xsl:output method="xhtml" exclude-result-prefixes="#all"/>-->
    <xsl:output method="xhtml" encoding="UTF-8" version="1.0" omit-xml-declaration="yes"
        doctype-public="-//W3C//DTD XHTML 1.0 Strict//EN"
        doctype-system="http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd" indent="yes"
        exclude-result-prefixes="#all"/>

    <xsl:variable name="cssRelativeLocation">xsdDocHtml.css</xsl:variable>
    <xsl:variable name="cssCopyLocation" select="resolve-uri($cssRelativeLocation, base-uri())"/>

    <!-- When all the  components are in the same file (no split after some criteria) we will use FRAMES. So the index will be redirected in a $indexFile
and the components in a $mainFile. The output file will only contain the FRAMESET-->
    <xsl:variable name="isChunkMode" as="xs:boolean" xmlns:xs="http://www.w3.org/2001/XMLSchema">
        <xsl:choose>
            <xsl:when test="compare(/schemaDoc/splitInfo/@criteria, 'none') = 0"> false </xsl:when>
            <xsl:otherwise> true </xsl:otherwise>
        </xsl:choose>
    </xsl:variable>

    <!-- When  NO CHUNKS we will generate a frame html. The index in one file and the content in other-->
    <xsl:variable name="indexFile">indexList.html</xsl:variable>

    <xsl:variable name="mainFrame">mainFrame</xsl:variable>
    <xsl:variable name="indexFrame">indexFrame</xsl:variable>

    <!-- Traget for all the links. If we are using a FRAME representation of the html we need to specify which frame the refrerence will be opened in -->
    <xsl:variable name="target">
        <xsl:choose>
            <xsl:when test="boolean($isChunkMode)">
                <xsl:value-of select="$mainFrame"/>
            </xsl:when>
            <xsl:otherwise>_self</xsl:otherwise>
        </xsl:choose>
    </xsl:variable>

    <!-- Used to construct an id for identifying a property of  a component. This prefix will be added to the unique component id-->
    <xsl:variable name="idsPrefixMap">
        <entry key="properties">properties_</entry>
        <entry key="usedBy">usedBy_</entry>
        <entry key="attributes">attributes_</entry>
        <entry key="children">children_</entry>
        <entry key="source">source_</entry>
        <entry key="instance">instance_</entry>
        <entry key="facets">facets_</entry>
    </xsl:variable>

    <xsl:variable name="buttonPrefix">button_</xsl:variable>

    <xsl:template name="createJsIdsArray">
        <xsl:param name="arrayName"/>
        <xsl:param name="nodes"/>
        <xsl:text>var </xsl:text>
        <xsl:value-of select="$arrayName"/>
        <xsl:text>= new Array(</xsl:text>
        <xsl:for-each select="$nodes">
            <xsl:if test="position()!=1">
                <xsl:text>, </xsl:text>
            </xsl:if>
            <xsl:text>'</xsl:text>
            <xsl:value-of select="func:getDivId(.)"/>
            <xsl:text>'</xsl:text>
        </xsl:for-each>
        <xsl:text>);</xsl:text>
    </xsl:template>
    <xsl:variable name="javascript" xml:space="preserve">
            <xsl:call-template name="createJsIdsArray">
                <xsl:with-param name="arrayName">propertiesBoxes</xsl:with-param>
                <xsl:with-param name="nodes" select="/schemaDoc/*[@id]/properties"/>
            </xsl:call-template> 
        <xsl:call-template name="createJsIdsArray">
            <xsl:with-param name="arrayName">facetsBoxes</xsl:with-param>
            <xsl:with-param name="nodes" select="/schemaDoc/*[@id]/facets"/>
        </xsl:call-template>
            <xsl:call-template name="createJsIdsArray">
                <xsl:with-param name="arrayName">usedByBoxes</xsl:with-param>
                <xsl:with-param name="nodes" select="/schemaDoc/*[@id]/usedBy"/>
            </xsl:call-template>
            <xsl:call-template name="createJsIdsArray">
                <xsl:with-param name="arrayName">attributesBoxes</xsl:with-param>
                <xsl:with-param name="nodes" select="/schemaDoc/*[@id]/attributes"/>
            </xsl:call-template>
            <xsl:call-template name="createJsIdsArray">
                <xsl:with-param name="arrayName">sourceBoxes</xsl:with-param>
                <xsl:with-param name="nodes" select="/schemaDoc/*[@id]/source"/>
            </xsl:call-template>
            <xsl:call-template name="createJsIdsArray">
                <xsl:with-param name="arrayName">instanceBoxes</xsl:with-param>
                <xsl:with-param name="nodes" select="/schemaDoc/*[@id]/instance"/>
            </xsl:call-template>
        var button_prefix = '<xsl:value-of select="$buttonPrefix"/>';
        <xsl:text disable-output-escaping="yes">
        /**
        * Returns an element in the current HTML document.
        *
        * @param elementID Identifier of HTML element
        * @return               HTML element object
        */
        function getElementObject(elementID) {
            var elemObj = null;
            if (document.getElementById) {
                elemObj = document.getElementById(elementID);
            }
            return elemObj;
        }
        
        /**
        * Switches the state of a collapseable box, e.g.
        * if it's opened, it'll be closed, and vice versa.
        *
        * @param boxID Identifier of box
        */
        function switchState(boxID) {
            var boxObj = getElementObject(boxID);
            var buttonObj = getElementObject(button_prefix + boxID);
            if (boxObj == null || buttonObj == null) {
                // Box or button not found
            } else if (boxObj.style.display == "none") {
                // Box is closed, so open it
                openBox(boxObj, buttonObj);
            } else if (boxObj.style.display == "block") {
                // Box is opened, so close it
                closeBox(boxObj, buttonObj);
            }
        }
        
        /**
        * Opens a collapseable box.
        *
        * @param boxObj       Collapseable box
        * @param buttonObj Button controlling box
        */
        function openBox(boxObj, buttonObj) {
            if (boxObj == null || buttonObj == null) {
                // Box or button not found
            } else {
                // Change 'display' CSS property of box
                boxObj.style.display = "block";
                
                // Change text of button
                if (boxObj.style.display == "block") {
                    buttonObj.value = " - ";
                }
            }
        }
        
        /**
        * Closes a collapseable box.
        *
        * @param boxObj       Collapseable box
        * @param buttonObj Button controlling box
        */
        function closeBox(boxObj, buttonObj) {
            if (boxObj == null || buttonObj == null) {
                // Box or button not found
            } else {
                // Change 'display' CSS property of box
                boxObj.style.display = "none";
                
                // Change text of button
                if (boxObj.style.display == "none") {
                    buttonObj.value = " + ";
                }
            }
        }

        function switchStateForAll(buttonObj, boxList) {
            if (buttonObj == null) {
                // button not found
            } else if (buttonObj.value == "+") {
                // Expand all
                 expandAll(boxList);
                 buttonObj.value = "-";
            } else if (buttonObj.value == "-") {
                // Collapse all
                collapseAll(boxList);
                buttonObj.value = "+";
            }
        }

        /**
        * Closes all boxes in a given list.
        *
        * @param boxList Array of box IDs
        */
        function collapseAll(boxList) {
            var idx;
            for (idx = 0; idx &lt; boxList.length; idx++) {
                var boxObj = getElementObject(boxList[idx]);
                var buttonObj = getElementObject(button_prefix + boxList[idx]);
                closeBox(boxObj, buttonObj);
            }
        }
            
        /**
        * Open all boxes in a given list.
        *
        * @param boxList Array of box IDs
        */
        function expandAll(boxList) {
            var idx;
            for (idx = 0; idx &lt; boxList.length; idx++) {
                var boxObj = getElementObject(boxList[idx]);
                var buttonObj = getElementObject(button_prefix + boxList[idx]);
                openBox(boxObj, buttonObj);
            }
        }
</xsl:text>
    </xsl:variable>

    <xsl:function name="func:getDivId" as="xs:string" xmlns:xs="http://www.w3.org/2001/XMLSchema">
        <xsl:param name="node"/>
        <xsl:value-of
            select="concat($idsPrefixMap/*[@key=local-name($node)]/text(), $node/parent::node()/@id)"
        />
    </xsl:function>

    <xsl:function name="func:getButtonId" as="xs:string" xmlns:xs="http://www.w3.org/2001/XMLSchema">
        <xsl:param name="node"/>
        <xsl:value-of select="concat($buttonPrefix/text() , func:getDivId($node))"/>
    </xsl:function>


    <xsl:variable name="schemaTypeLabels">
        <entry key="main">Main schema</entry>
        <entry key="included">Included schema</entry>
        <entry key="imported">Imported schema</entry>
    </xsl:variable>

    <xsl:variable name="componentTypeLabels">
        <entry key="Element">Element</entry>
        <entry key="Attribute">Attribute</entry>
        <entry key="Complex_Type">Complex Type</entry>
        <entry key="Element_Group">Element Group</entry>
        <entry key="Attribute_Group">Attribute Group</entry>
        <entry key="Simple_Type">Simple Type</entry>
        <entry key="Schema">Schema</entry>
    </xsl:variable>


    <xsl:template match="schemaDoc">
        <xsl:if test="exists(./schema[@type='main'])">
            <!-- This way we make sure the CSS will only be copied once-->
            <xsl:result-document href="{$cssCopyLocation}" method="text">
                <xsl:value-of disable-output-escaping="yes"
                    select="unparsed-text($cssRelativeLocation,'UTF-8')"/>
            </xsl:result-document>
        </xsl:if>

        <xsl:choose>
            <xsl:when test="boolean($isChunkMode) and exists(./schema[@type='main'])">
                <xsl:result-document href="{resolve-uri($mainFile, base-uri())}" method="xhtml"
                    indent="no" exclude-result-prefixes="#all">
                    <html xmlns="http://www.w3.org/1999/xhtml">
                        <head>
                            <title>Schema Documentation - <xsl:value-of select="./title/text()"
                                /></title>
                            <link rel="stylesheet" href="{$cssRelativeLocation}" type="text/css"/>
                        </head>
                        <xsl:if test="boolean($isChunkMode)">
                            <!-- When all the documentation is in one file we will generate a html with frames -->
                            <frameset cols="20%, 80%">
                                <xsl:element name="frame">
                                    <xsl:attribute name="name" select="$indexFrame"/>
                                    <xsl:attribute name="src" select="$indexFile"/>
                                </xsl:element>
                                <xsl:element name="frame">
                                    <xsl:attribute name="name" select="$mainFrame"/>
                                    <xsl:attribute name="src"
                                        select="concat(substring-before(base-uri(),'.'), '.html')"/>
                                </xsl:element>
                            </frameset>
                        </xsl:if>
                    </html>
                </xsl:result-document>
            </xsl:when>
        </xsl:choose>

        <html xmlns="http://www.w3.org/1999/xhtml">
            <head>
                <title>Schema Documentation - <xsl:value-of select="./title/text()"/></title>
                <link rel="stylesheet" href="{$cssRelativeLocation}" type="text/css"/>
                <script type="text/javascript">
                            <xsl:value-of select="$javascript" disable-output-escaping="yes"/>
                       </script>
            </head>
            <xsl:call-template name="main"/>
        </html>
    </xsl:template>

    <xsl:template name="reference">
        <xsl:param name="ref" select="."/>
        <xsl:choose>
            <xsl:when test="exists($ref/@refId)">
                <b>
                    <xsl:element name="a">
                        <xsl:attribute name="href"
                            select="concat(substring-before($ref/@base,'.'), '.html#', $ref/@refId)"/>
                        <xsl:attribute name="target" select="$target"/>
                        <xsl:attribute name="title">
                            <xsl:choose>
                                <xsl:when test="compare('', $ref/@ns) = 0">No namespace</xsl:when>
                                <xsl:otherwise>
                                    <xsl:value-of select="$ref/@ns"/>
                                </xsl:otherwise>
                            </xsl:choose>
                        </xsl:attribute>
                        <xsl:copy-of select="$ref/text()"/>
                    </xsl:element>
                </b>
            </xsl:when>
            <xsl:otherwise>
                <b>
                    <xsl:copy-of select="$ref/text()"/>
                </b>
            </xsl:otherwise>
        </xsl:choose>
    </xsl:template>

    <xsl:template name="index">
        <h2>
            <a id="INDEX">Table of Contents</a>
        </h2>
        <!-- Generate links grouped by the namespace of the component-->
        <xsl:if test="contains(@groupBy, 'namespace')">
            <xsl:variable name="boxId">groupByNs</xsl:variable>
            <div class="level1">
                <p>
                    <input id="button_{$boxId}" type="button" value="-"
                        onclick="switchState('{$boxId}');" class="control"/>
                    <span class="indexGroupTitle"> Group by Namespace </span>
                </p>
                <div id="{$boxId}" style="display:block">
                    <xsl:for-each-group select="ref" group-by="@ns">
                        <xsl:variable name="ns">
                            <xsl:choose>
                                <xsl:when test="compare('', @ns) = 0">No namespace</xsl:when>
                                <xsl:otherwise>
                                    <xsl:value-of select="@ns"/>
                                </xsl:otherwise>
                            </xsl:choose>
                        </xsl:variable>
                        <div class="level2">
                            <p>
                                <input id="button_{$ns}" type="button" value="-"
                                    onclick="switchState('{$ns}');" class="control"/>
                                <span class="indexGroup">
                                    <xsl:value-of select="$ns"/>
                                </span>
                            </p>
                            <div id="{$ns}" style="display:block">
                                <xsl:call-template name="indexGroupByComponent">
                                    <xsl:with-param name="refSeq" select="current-group()"/>
                                    <xsl:with-param name="prefix" select="$ns"/>
                                </xsl:call-template>
                            </div>
                        </div>
                    </xsl:for-each-group>
                </div>
            </div>
        </xsl:if>

        <!-- Generate links grouped by the type of the component-->
        <xsl:if test="contains(@groupBy, 'component')">
            <xsl:variable name="boxId">groupByCType</xsl:variable>
            <div class="level1">
                <p>
                    <input id="button_{$boxId}" type="button" value="-"
                        onclick="switchState('{$boxId}');" class="control"/>
                    <span class="indexGroupTitle"> Group by Component Type </span>
                </p>
                <div id="{$boxId}" style="display:block">
                    <xsl:call-template name="indexGroupByComponent">
                        <xsl:with-param name="refSeq" select="ref"/>
                    </xsl:call-template>
                </div>
            </div>
        </xsl:if>
        
        <!-- Generate links grouped by the location of the component-->
        <xsl:if test="contains(@groupBy, 'location')">
            <xsl:variable name="boxId">groupByLocation</xsl:variable>
            <div class="level1">
                <p>
                    <input id="button_{$boxId}" type="button" value="-"
                        onclick="switchState('{$boxId}');" class="control"/>
                    <span class="indexGroupTitle"> Group by Location </span>
                </p>
                <div id="{$boxId}" style="display:block">
                    <xsl:for-each-group select="ref" group-by="@schemaLocation">
                        <xsl:variable name="schemaLocation">
                            <xsl:choose>
                                <xsl:when test="compare('', @schemaLocation) = 0"></xsl:when>
                                <xsl:otherwise>
                                    <xsl:value-of select="@schemaLocation"/>
                                </xsl:otherwise>
                            </xsl:choose>
                        </xsl:variable>
                        <div class="level2">
                            <p>
                                <input id="button_{$schemaLocation}" type="button" value="-"
                                    onclick="switchState('{$schemaLocation}');" class="control"/>
                                <span class="indexGroup">
                                    <xsl:value-of select="$schemaLocation"/>
                                </span>
                            </p>
                            <div id="{$schemaLocation}" style="display:block">
                                <xsl:call-template name="indexGroupByLocation">
                                    <xsl:with-param name="refSeq" select="current-group()"/>
                                    <xsl:with-param name="schemaLocation" select="$schemaLocation"/>
                                </xsl:call-template>
                            </div>
                        </div>
                    </xsl:for-each-group>
                </div>
            </div>
        </xsl:if>
    </xsl:template>
    
    <xsl:template name="indexGroupByComponent">
        <xsl:param name="refSeq" required="yes"/>
        <xsl:param name="prefix"/>
        <xsl:for-each-group select="$refSeq" group-by="@refType">
            <xsl:variable name="refType" select="@refType"/>
            <div class="level2">
                <p>
                    <input id="button_{$prefix}{$refType}" type="button" value="-"
                        onclick="switchState('{$prefix}{$refType}');" class="control"/>
                    <span class="indexGroup">
                        <xsl:variable name="currentComponent" select="."/>
                        <xsl:value-of
                            select="$componentTypeLabels/*[@key=$currentComponent/@refType]"
                        />
                    </span>
                </p>
                <div id="{$prefix}{$refType}" style="display:block">
                    <ul>
                        <xsl:for-each select="current-group()">
                            <xsl:sort select="text()"/>
                            <li>
                                <xsl:call-template name="reference"/>
                            </li>
                        </xsl:for-each>
                    </ul>
                </div>
            </div>
        </xsl:for-each-group>
    </xsl:template>

    <xsl:template name="indexGroupByLocation">
        <xsl:param name="refSeq" required="yes"/>
        <xsl:param name="schemaLocation"/>
        <xsl:for-each-group select="$refSeq" group-by="@refType">
            <xsl:variable name="refType" select="@refType"/>
            <div class="level2">
                <p>
                    <input id="button_{$schemaLocation}{$refType}" type="button" value="-"
                        onclick="switchState('{$schemaLocation}{$refType}');" class="control"/>
                    <span class="indexGroup">
                        <xsl:variable name="currentComponent" select="."/>
                        <xsl:value-of
                            select="$componentTypeLabels/*[@key=$currentComponent/@refType]"
                        />
                    </span>
                </p>
                <div id="{$schemaLocation}{$refType}" style="display:block">
                    <ul>
                        <xsl:for-each select="current-group()">
                            <xsl:sort select="text()"/>
                            <li>
                                <xsl:call-template name="reference"/>
                            </li>
                        </xsl:for-each>
                    </ul>
                </div>
            </div>
        </xsl:for-each-group>
    </xsl:template>

    <xsl:template match="schema">
        <xsl:call-template name="component">
            <xsl:with-param name="type">
                <xsl:variable name="currentSchema" select="."/>
                <xsl:value-of select="$schemaTypeLabels/*[@key=$currentSchema/@type]"/>
            </xsl:with-param>
        </xsl:call-template>
    </xsl:template>

    <xsl:template match="element">
        <xsl:call-template name="component">
            <xsl:with-param name="type">Element</xsl:with-param>
        </xsl:call-template>
    </xsl:template>

    <xsl:template match="complexType">
        <xsl:call-template name="component">
            <xsl:with-param name="type">Complex Type</xsl:with-param>
        </xsl:call-template>
    </xsl:template>

    <xsl:template match="simpleType">
        <xsl:call-template name="component">
            <xsl:with-param name="type">Simple Type</xsl:with-param>
        </xsl:call-template>
    </xsl:template>

    <xsl:template match="attribute">
        <xsl:call-template name="component">
            <xsl:with-param name="type">Attribute</xsl:with-param>
        </xsl:call-template>
    </xsl:template>

    <xsl:template match="attributeGroup">
        <xsl:call-template name="component">
            <xsl:with-param name="type">Attribute Group</xsl:with-param>
        </xsl:call-template>
    </xsl:template>

    <xsl:template match="elementGroup">
        <xsl:call-template name="component">
            <xsl:with-param name="type">Element Group</xsl:with-param>
        </xsl:call-template>
    </xsl:template>

    <xsl:function name="func:createControl" as="item()">
        <xsl:param name="boxID"/>
        <xsl:param name="buttonID"/>
        <input id="{$buttonID}" type="button" value="-" onclick="switchState('{$boxID}');"
            class="control"/>
    </xsl:function>

    <xsl:template match="facets">
        <xsl:variable name="boxID" select="func:getDivId(.)"/>
        <tr>
            <td>
                <b>Facets</b>
                <xsl:text> </xsl:text>
                <xsl:copy-of select="func:createControl($boxID, func:getButtonId(.))"/>
            </td>
            <td>
                <div id="{$boxID}" style="display:block">
                    <table>
                        <xsl:for-each select="./facet">
                            <tr>
                                <td>
                                    <xsl:value-of select="@name"/>
                                </td>
                                <td>
                                    <b>
                                        <xsl:value-of select="@value"/>
                                    </b>
                                </td>
                            </tr>
                        </xsl:for-each>
                    </table>
                </div>
            </td>
        </tr>
    </xsl:template>

    <xsl:template match="properties">
        <xsl:variable name="boxID" select="func:getDivId(.)"/>
        <tr>
            <td>
                <b>Properties</b>
                <xsl:text> </xsl:text>
                <xsl:copy-of select="func:createControl($boxID, func:getButtonId(.))"/>
            </td>
            <td>
                <div id="{$boxID}" style="display:block">
                    <table>
                        <xsl:for-each select="./property">
                            <tr>
                                <td class="pre">
                                    <xsl:value-of select="name"/>
                                </td>
                                <td>
                                    <b>
                                        <xsl:value-of select="value"/>
                                    </b>
                                </td>
                            </tr>
                        </xsl:for-each>
                    </table>
                </div>
            </td>
        </tr>
    </xsl:template>

    <xsl:template match="namespace">
        <tr>
            <td>
                <b>Namespace</b>
            </td>
            <td>
                <xsl:choose>
                    <xsl:when test="compare('', text()) != 0">
                        <xsl:value-of select="text()"/>
                    </xsl:when>
                    <xsl:otherwise>No namespace</xsl:otherwise>
                </xsl:choose>
            </td>
        </tr>
    </xsl:template>

    <xsl:template match="schemaLocation">
        <tr>
            <td>
                <b>Schema location</b>
            </td>
            <td>
                <xsl:value-of select="text()"/>
            </td>
        </tr>
    </xsl:template>

    <xsl:template match="usedBy">
        <xsl:variable name="boxID" select="func:getDivId(.)"/>
        <tr>
            <td>
                <b>Used by</b>
                <xsl:text> </xsl:text>
                <xsl:copy-of select="func:createControl($boxID, func:getButtonId(.))"/>
            </td>
            <td>
                <div id="{$boxID}" style="display:block">
                    <table>
                        <xsl:for-each-group select="./ref" group-by="@refType">
                            <tr>
                                <td class="pre">
                                    <b>
                                        <xsl:variable name="currentRef" select="."/>
                                        <xsl:value-of
                                            select="$componentTypeLabels/*[@key=$currentRef/@refType]"/>
                                        <xsl:if test="count(current-group()) > 1">
                                            <xsl:text>s</xsl:text>
                                        </xsl:if>
                                        <xsl:text> </xsl:text>
                                    </b>
                                </td>
                                <td>
                                    <xsl:for-each select="current-group()">
                                        <xsl:sort select="text()"/>
                                        <xsl:call-template name="reference"/>
                                        <xsl:if test="position() != last()">
                                            <xsl:text>, </xsl:text>
                                        </xsl:if>
                                    </xsl:for-each>
                                </td>
                            </tr>
                        </xsl:for-each-group>
                    </table>
                </div>
            </td>
        </tr>
    </xsl:template>

    <xsl:template match="attributes">
        <xsl:variable name="boxID" select="func:getDivId(.)"/>
        <tr>
            <td>
                <b>Attributes</b>
                <xsl:text> </xsl:text>
                <xsl:copy-of select="func:createControl($boxID, func:getButtonId(.))"/>
            </td>
            <td>
                <div id="{$boxID}" style="display:block">
                    <table>
                        <thead>
                            <tr>
                                <th>QName</th>
                                <th>Type</th>
                                <th>Fixed</th>
                                <th>Default</th>
                                <th>Use</th>
                                <th>Annotation</th>
                            </tr>
                        </thead>
                        <xsl:for-each select="attr">
                            <xsl:sort select="ref/text()"/>
                            <tr>
                                <td>
                                    <xsl:call-template name="reference">
                                        <xsl:with-param name="ref" select="ref"/>
                                    </xsl:call-template>
                                </td>
                                <td>
                                    <xsl:call-template name="typeEmitter">
                                        <xsl:with-param name="type" select="type"/>
                                    </xsl:call-template>
                                </td>
                                <td>
                                    <xsl:value-of select="fixed"/>
                                </td>
                                <td>
                                    <xsl:value-of select="default"/>
                                </td>
                                <td>
                                    <xsl:value-of select="use"/>
                                </td>
                                <td>
                                    <xsl:value-of select="annotation"/>
                                </td>
                            </tr>
                        </xsl:for-each>
                    </table>
                </div>
            </td>
        </tr>
    </xsl:template>

    <xsl:template name="component">
        <xsl:param name="type"/>
        <xsl:element name="a">
            <xsl:attribute name="id" select="@id"/>
        </xsl:element>
        <xsl:if test="not(boolean($isChunkMode))">
            <b>
                <a href="#INDEX">[Table of Contents]</a>
            </b>
        </xsl:if>
        <table>
            <caption>
                <xsl:value-of select="$type"/>
                <xsl:text> </xsl:text>
                <span class="qname">
                    <xsl:for-each select="declarationPath/ref">
                        <xsl:call-template name="reference"/>
                        <xsl:text>/</xsl:text>
                    </xsl:for-each>
                    <xsl:value-of select="qname/text()"/>
                </span>
            </caption>
            <tbody>
                <xsl:apply-templates/>
            </tbody>
        </table>
    </xsl:template>

    <xsl:template name="typeEmitter">
        <xsl:param name="type"/>
        <xsl:for-each select="$type/node()">
            <xsl:choose>
                <xsl:when test="compare('ref', local-name()) = 0">
                    <xsl:call-template name="reference">
                        <xsl:with-param name="ref" select="."/>
                    </xsl:call-template>
                </xsl:when>
                <xsl:otherwise>
                    <xsl:value-of select="."/>
                </xsl:otherwise>
            </xsl:choose>
        </xsl:for-each>
    </xsl:template>

    <xsl:template match="element/type | complexType/type | attribute/type | simpleType/type">
        <tr>
            <td>
                <b>Type</b>
            </td>
            <td>
                <xsl:call-template name="typeEmitter">
                    <xsl:with-param name="type" select="."/>
                </xsl:call-template>
            </td>
        </tr>
    </xsl:template>

    <!-- Show the hierarchy type  -->
    <xsl:template name="hierarchyOutput">
        <xsl:param name="refs"/>
        <xsl:param name="index" as="xs:integer" select="1"
            xmlns:xs="http://www.w3.org/2001/XMLSchema"/>

        <ul>
            <li>
                <xsl:call-template name="reference">
                    <xsl:with-param name="ref" select="$refs[$index]"/>
                </xsl:call-template>

                <xsl:if test="$index &lt; count($refs)">
                    <xsl:call-template name="hierarchyOutput">
                        <xsl:with-param name="refs" select="$refs"/>
                        <xsl:with-param name="index" select="$index + 1"/>
                    </xsl:call-template>
                </xsl:if>
            </li>
        </ul>
    </xsl:template>

    <xsl:template match="typeHierarchy">
        <tr>
            <td>
                <b>Type hierarchy</b>
            </td>
            <td>
                <xsl:call-template name="hierarchyOutput">
                    <xsl:with-param name="refs" select="ref"/>
                </xsl:call-template>
            </td>
        </tr>
    </xsl:template>

    <xsl:template match="model">
        <tr>
            <td>
                <b>Model</b>
            </td>
            <td>
                <xsl:call-template name="groupTemplate">
                    <xsl:with-param name="group" select="group[1]"/>
                </xsl:call-template>
            </td>
        </tr>
    </xsl:template>

    <xsl:template name="groupTemplate">
        <xsl:param name="group" select="."/>
        <xsl:variable name="compositor">
            <xsl:value-of select="$group/@compositor"/>
        </xsl:variable>
        <xsl:variable name="separator">
            <xsl:if test="compare($compositor, 'sequence') = 0">
                <xsl:text> , </xsl:text>
            </xsl:if>
            <xsl:if test="compare($compositor, 'choice') = 0">
                <xsl:text> | </xsl:text>
            </xsl:if>
            <xsl:if test="compare($compositor, 'all') = 0">
                <xsl:text> </xsl:text>
            </xsl:if>
        </xsl:variable>

        <xsl:if test="compare($compositor, 'all') = 0">
            <xsl:text>ALL(</xsl:text>
        </xsl:if>
        <xsl:for-each
            select="$group/*[compare(local-name(.), 'group') = 0 or compare(local-name(.), 'ref') = 0]">
            <xsl:if test="position() != 1">
                <xsl:value-of select="$separator"/>
            </xsl:if>
            <xsl:choose>
                <xsl:when test="compare(local-name(.), 'ref') = 0">
                    <xsl:call-template name="reference"/>
                </xsl:when>
                <xsl:otherwise>
                    <xsl:variable name="nextCompositor">
                        <xsl:value-of select="@compositor"/>
                    </xsl:variable>

                    <xsl:if test="compare($compositor, $nextCompositor) != 0">
                        <xsl:text>(</xsl:text>
                    </xsl:if>

                    <xsl:call-template name="groupTemplate"/>

                    <xsl:if test="compare($compositor, $nextCompositor) != 0">
                        <xsl:text>)</xsl:text>
                    </xsl:if>
                </xsl:otherwise>
            </xsl:choose>
        </xsl:for-each>

        <xsl:if test="compare($compositor, 'all') = 0">
            <xsl:text>)</xsl:text>
        </xsl:if>
    </xsl:template>

    <xsl:template match="children">
        <tr>
            <td>
                <b>Children</b>
            </td>
            <td>
                <xsl:for-each select="child">
                    <xsl:sort select="ref/text()"/>
                    <xsl:call-template name="reference">
                        <xsl:with-param name="ref" select="ref"/>
                    </xsl:call-template>
                    <xsl:if test="position() != last()">
                        <xsl:text>, </xsl:text>
                    </xsl:if>
                </xsl:for-each>
            </td>
        </tr>
    </xsl:template>

    <xsl:template match="source | instance">
        <xsl:variable name="boxID" select="func:getDivId(.)"/>
        <tr>
            <td>
                <b>
                    <xsl:choose>
                        <xsl:when test="compare(local-name(.), 'source') = 0">Source</xsl:when>
                        <xsl:otherwise>Instance</xsl:otherwise>
                    </xsl:choose>
                    <xsl:text> </xsl:text>
                    <xsl:copy-of select="func:createControl($boxID, func:getButtonId(.))"/>
                </b>
            </td>
            <td>
                <div id="{$boxID}" style="display:block">
                    <pre><div class="preWrap">
                        <xsl:for-each select="token">
                               <xsl:element name="span">
                                        <xsl:attribute name="class" select="@type"/>
                                         <xsl:copy-of select="text()"/>
                                </xsl:element>
                        </xsl:for-each>
                        </div></pre>
                </div>
            </td>
        </tr>
    </xsl:template>

    <xsl:template match="constraints">
        <tr>
            <td>
                <b>Identity constraints</b>
            </td>
            <td>
                <table>
                    <thead>
                        <tr>
                            <th>Type</th>
                            <th>QName</th>
                            <th>Refer</th>
                            <th>Selector</th>
                            <th>Field(s)</th>
                        </tr>
                    </thead>
                    <xsl:for-each select="constraint">
                        <tr>
                            <td>
                                <xsl:value-of select="type"/>
                            </td>
                            <td>
                                <xsl:value-of select="name"/>
                            </td>
                            <td>
                                <xsl:value-of select="refer"/>
                            </td>
                            <td>
                                <xsl:value-of select="selector"/>
                            </td>
                            <td>
                                <xsl:value-of select="fields"/>
                            </td>
                        </tr>
                    </xsl:for-each>
                </table>
            </td>
        </tr>
    </xsl:template>

    <xsl:template match="substitutionGroup | substitutionGroupAffiliation">
        <tr>
            <td>
                <b>
                    <xsl:choose>
                        <xsl:when test="compare(local-name(.), 'substitutionGroup') = 0"
                            >Substitution Group</xsl:when>
                        <xsl:otherwise>Substitution Group Affiliation</xsl:otherwise>
                    </xsl:choose>
                </b>
            </td>
            <td>
                <ul>
                    <xsl:for-each select="ref">
                        <li>
                            <xsl:call-template name="reference"/>
                        </li>
                    </xsl:for-each>
                </ul>
            </td>
        </tr>
    </xsl:template>

    <xsl:template match="annotations">
        <tr>
            <td>
                <b>Annotations</b>
            </td>
            <td>
                <ul>
                    <xsl:for-each select="annotation">
                        <li>
                            <xsl:copy-of select="."/>
                        </li>
                    </xsl:for-each>
                </ul>
            </td>
        </tr>
    </xsl:template>

    <xsl:template name="main">
        <body>
            <xsl:if test="not($isChunkMode) or not(exists(index))">
                <table class="globalControls">
                    <tr>
                        <td class="globalControl">
                            <span class="globalControlName"> Properties </span>
                            <span>
                                <input type="button" value="-"
                                    onclick="switchStateForAll(this, propertiesBoxes);"
                                    class="control"/>
                            </span>
                        </td>
                        <td class="globalControl">
                            <span class="globalControlName"> Used by </span>
                            <span>
                                <input type="button" value="-"
                                    onclick="switchStateForAll(this, usedByBoxes);" class="control"
                                />
                            </span>
                        </td>
                        <td class="globalControl">
                            <span class="globalControlName"> Attributes </span>
                            <span>
                                <input type="button" value="-"
                                    onclick="switchStateForAll(this, attributesBoxes);"
                                    class="control"/>
                            </span>
                        </td>
                        <td class="globalControl">
                            <span class="globalControlName">Instance</span>
                            <span>
                                <input type="button" value="-"
                                    onclick="switchStateForAll(this, instanceBoxes);"
                                    class="control"/>
                            </span>
                        </td>
                        <td class="globalControl">
                            <span class="globalControlName">Source</span>
                            <span>
                                <input type="button" value="-"
                                    onclick="switchStateForAll(this, sourceBoxes);" class="control"
                                />
                            </span>
                        </td>
                    </tr>
                </table>
            </xsl:if>
            <xsl:for-each select="index">
                <xsl:call-template name="index"/>
            </xsl:for-each>
            <xsl:apply-templates/>
        </body>
    </xsl:template>

    <xsl:template match="text()"/>
</xsl:stylesheet>
